# Function Reference

This is a docstrings based and automatically generated Python function reference of *Bankr*. 


## The Command Line Interface

The CLI is described briefly in this documentation under [Home](index.md#commands). However, the preferable source of help is `bankr [COMMAND] -h`. The CLI itself is in English language, however, the output of *Bankr* is translated, currently to English or German.

::: src.bankr.cli.commands


## Functions related to File Activity

::: src.bankr.files


## Functions related to Calculations

::: src.bankr.calc


## Functions related to TUI

::: src.bankr.tuitable

::: src.bankr.tuiplot